package com.mydomain.helloworld;

import java.util.ArrayList;
import java.util.List;

import javax.ejb.Remove;
import javax.ejb.Stateful;

import org.jboss.seam.annotations.Destroy;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.annotations.Out;
import org.jboss.seam.annotations.datamodel.DataModel;
import org.jboss.seam.core.FacesMessages;
import org.jboss.seam.log.Log;

import org.hibernate.validator.Length;
import org.hibernate.validator.NotNull;

import java.util.Date;

import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Basic;

@Stateful
@Name("pojo")
public class PojoBean implements Pojo {

	@Logger
	private Log log;
	
	//LAB TIP - various form fields that the facelets will use. setters/getters too.
	private String searchString = "";
	private String inputField;
	private Date inputDate;
	private String passwordField;
	
	//LAB TIP - Results for the AJAX type ahead stuff.
	@DataModel
	private List<DataBean> results;
	
	private int resultsRowCount = 0;
	
	//LAB TIP - messages can be added via this component that is an APPLICATION scoped Seam component
	@In
	FacesMessages facesMessages;
	
	@Destroy @Remove
	public void destroy() {}
	
	//LAB TIP - Add some data to the "results" list so that the AJAX type ahead stuff has data	
	public void find() {
		log.info("pojo.find action called");
		if (results == null)
		{
			results = new ArrayList<DataBean>();
		}
		
		results.clear();
		
		ArrayList<DataBean> dataList = new ArrayList<DataBean>();
		dataList.add(new DataBean("Albert"));
		dataList.add(new DataBean("Al"));
		dataList.add(new DataBean("Benard"));
		dataList.add(new DataBean("Ben"));	
		dataList.add(new DataBean("Charles"));
		dataList.add(new DataBean("Chris"));
		dataList.add(new DataBean("Christopher"));
		dataList.add(new DataBean("Dirk"));
		dataList.add(new DataBean("Donovan"));
		
		 for (DataBean dataBean : dataList) {  
			 if (dataBean.getData().startsWith(searchString))
				 results.add(dataBean);
		 }
		
		log.info("pojo results are: " + results.toString());
		resultsRowCount = results.size();
	}

	//LAB TIP - call a method that does nothing more than log info and add a message from the resource bundle
	public String method() {
		// implement your business logic here
		log.info("pojo.method action called");
		
		facesMessages.addFromResourceBundle("messages.msg");
		facesMessages.add("input field = " + inputField);
		return "success";
	}

	public String getSearchString() {
		return searchString;
	}

	public void setSearchString(String searchString) {
		this.searchString = searchString;
	}
	
	//LAB TIP - add hibernate validator to check for a field length min/max
	@NotNull @Length(min=5, max=15)
	public String getInputField() {
		return inputField;
	}

	public void setInputField(String inputField) {
		this.inputField = inputField;
	}
	
    //LAB TIP - add hibernate validator to check for a field length min/max
	@NotNull @Length(min=5, max=15)
	public String getPasswordField() {
		return passwordField;
	}

	public void setPasswordField(String passwordField) {
		this.passwordField = passwordField;
	}
	
    //LAB TIP - Seam date format annotations
	@NotNull
	@Basic @Temporal(TemporalType.DATE) 
	public Date getInputDate()
	{
		return inputDate;		
	
	}
	
	public void setInputDate(Date aDate)
	{
		inputDate = aDate;
	}
}
